/*****************************************************************************
 * Sun Public License Notice
 *
 * The contents of this file are subject to the Sun Public License Version
 * 1.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is available at http://www.sun.com/

 * The Original Code is the CVS Client Library.
 * The Initial Developer of the Original Code is Robert Greig.
 * Portions created by Robert Greig are Copyright (C) 2000.
 * All Rights Reserved.

 * Contributor(s): Robert Greig.
 *****************************************************************************/
package org.netbeans.lib.cvsclient.response;

import java.io.*;

import org.netbeans.lib.cvsclient.event.*;
import org.netbeans.lib.cvsclient.util.*;

/**
 * Handles standard message responses
 * @author  Robert Greig
 */
class MessageResponse implements Response {

    private boolean terminating = false;

    private String firstWord;
    
    public MessageResponse() {
        // do nothing
    }
    
    public MessageResponse(String initialWord) {
        firstWord = initialWord;
    }
    
    /**
     * Process the data for the response.
     * @param dis the data inputstream allowing the client to read the server's
     * response. Note that the actual response name has already been read
     * and the inputstream is positioned just before the first argument, if any.
     */
    public void process(LoggedDataInputStream dis, ResponseServices services)
            throws ResponseException {
        try {
            ByteArray bytes = dis.readLineBytes();
            String line = bytes.getStringFromBytes();
            if (firstWord != null) {
                line = firstWord + " " + line; //NOI18N
            }
            terminating |= line.endsWith(SpecialResponses.SERVER_ABORTED);
            terminating |= line.endsWith(SpecialResponses.SERVER_ABORTED_2);
            terminating |= line.endsWith(SpecialResponses.SERVER_ABORTED_3);
            terminating &= dis.available() == 0;  // heuristics to relax SpecialResponses in commit messages...
            MessageEvent event = new MessageEvent(this, line, bytes.getBytes(), false);
            services.getEventManager().fireCVSEvent(event);
        }
        catch (EOFException ex) {
            throw new ResponseException(ex, ResponseException.getLocalMessage("CommandException.EndOfFile", null)); //NOI18N
        }
        catch (IOException ex) {
            throw new ResponseException(ex);
        }
    }

    /**
     * Is this a terminal response, i.e. should reading of responses stop
     * after this response. This is true for responses such as OK or
     * an error response
     * <p>
     * @see SpecialResponses.SERVER_ABORTED
     */
    public boolean isTerminalResponse() {
        return terminating;
    }
}